// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "DebugApplication.h"


Q_LOGGING_CATEGORY(KAMD_LOG_APPLICATION, "org.kde.kactivities.application", QtWarningMsg)

